---
name: Content/Accessible and inclusive language
slug: accessible-and-inclusive-language
icon: IconCustomerPlus
keywords:
  - copy instructions
  - copy rules
  - copy guidelines
  - content instructions
  - content rules
  - word list
  - language
  - race
  - racial
  - racist
  - racism
  - a11y
  - accessible
  - accessibility
  - disability
  - ableist
  - ableism
  - gender
  - gendered
  - ungendered
  - gender binary
  - sex
  - gender identity
  - gender-neutral
  - pronoun
  - inclusive content
---

# Accessible and inclusive language

<!-- keywords: inclusivity, inclusive content, inclusive language, word list -->

Our mission is to make commerce better for _everyone_. Building products for everyone means creating inclusive content.

The words we use have power. Writing for everyone, everywhere means that we don’t exclude or harm any of our merchants, even if these words have been normalized.

Write for more than one perspective, and limit assumptions or biases. For example, don’t assume that your audience is white, has a binary gender, or is nondisabled. Keep in mind that our merchants have intersectional identities, which means they can be from more than one historically-excluded group.

Try to write what you mean without metaphors so your content is easy to understand and localize. If you can’t think of an alternate term, then find another way to write what you want to say.

Test your content with a diverse audience by recruiting merchants from a variety of backgrounds, including historically-excluded groups, and create intersectionality-informed research objectives. Building inclusive experiences starts with involving diverse perspectives early on in the process.

---

## Accessible content

<!-- keywords: accessibility, accessible, a11y, disability, ableist, ableism -->

Using anti-ableist language is just one part of making accessible content at Shopify. Ableist language is content that holds bias towards the nondisabled experience, or discriminates against the disabled community.

Ableism can show up in language directly, as well as in metaphors and euphemisms. For example, “don’t let your marketing efforts fall on deaf ears”. Write what you mean, instead of using analogies, metaphors, or euphemisms.

Write content that centers around the person, not their disability.

### Words and phrases to avoid

Avoid the following words and phrases.

<h4 id="inspire-inspirational">Inspire, inspirational</h4>

This language and narrative around people with disabilities can be othering and reductive. It can also center an abled perception of those with disabilities (For example, “my life’s not that bad, look at them!”).

<h4 id="enable-disable">Enable, disable</h4>

Implies that disability is a less-desired or negative state.

<!-- usageblock -->

#### Do

Accounts are deactivated.

#### Don’t

Accounts are disabled.

<!-- end -->

<!-- usagelist -->

#### Do

- Turned on, turned off
- Active, inactive
- Activate, deactivate

#### Don’t

- Enable, enabled
- Disable, disabled

<!-- end -->

_Note: Because `disabled` is a valid state for HTML elements, usage of “disabled” is appropriate when talking about specific element states, just not overall feature functionality._

<!-- usagelist -->

#### Do

The checkbox is disabled.

<!-- end -->

<h4 id="normal-abnormal">Normal, abnormal</h4>

This language can imply that there’s something wrong with anyone outside of the majority.

<!-- usagelist -->

#### Do

- Typical
- Atypical

#### Don’t

- Normal
- Abnormal

<!-- end -->

<h4 id="deaf">Deaf</h4>

This language is often used to equate deafness or hearing impairment with ignorance or insensitivity, rather than refer to deafness itself or the Deaf community. Make sure to only use it when referencing actual deafness or the Deaf community, and not as a metaphor.

<h4 id="blind">Blind</h4>

As a metaphor, this can equate lack of vision to ignorance. Only use the term when referencing the disability itself.

<!-- usagelist -->

#### Do

- Unaware
- Gap

#### Don’t

- Blind
- Blind spot

<!-- end -->

<h4 id="insane-crazy">Insane, crazy</h4>

This language can stigmatize people with mental disabilities by using these words as modifiers for “unbelievable” or in a negative context.

<!-- usagelist -->

#### Do

- Wild
- Unbelievable
- Outrageous
- Intense
- Silly
- Strange

#### Don’t

- Insane
- Crazy

<!-- end -->

<h4 id="handicap">Handicap, handicapped</h4>

Handicap implies that the person is the issue, rather than the environment.

<!-- usagelist -->

#### Do

- Disability

#### Don’t

- Handicap
- Handicapped

<!-- end -->

<h4 id="wheelchair-bound">Wheelchair-bound</h4>

This term can reduce a person’s primary identity to using a wheelchair.

<!-- usagelist -->

#### Do

- Person who uses a wheelchair
- Person who uses an accessibility device

#### Don’t

- Wheelchair-bound

<!-- end -->

<h4 id="suffers-from">Suffers from...</h4>

This phrasing implies that having a disability equates to suffering.

<!-- usagelist -->

#### Do

- Experiences vision impairment

#### Don’t

- Suffers from vision impairment

<!-- end -->

<h4 id="just-only">Just, only</h4>

When we write a task is “only a few steps”, or this should “just take a minute”, it implies the task is easy, quick, or takes a minimal amount of effort. This can discourage people who might struggle with the task, or might take extra time to complete it.

---

## Anti-racist content

<!-- keywords: anti-racist, racism, racist, race, racial -->

Racist language expresses bias towards or against a particular race, or expresses the belief that some races are inferior to others. Always prioritize our merchants, partners, and buyers experience over perceived barriers to using anti-racist language.

**Tips:**

- Treat non-white or non-Western perspectives the same as white and Western perspectives. Non-Western ideals aren’t “exotic” or “strange”.
- Write what you mean instead of using an analogy or a metaphor. If you need a metaphor, then don’t use one that denotes “black” or “dark” as bad or negative, versus “white” or “light” as good or positive.
- Use terms in an appropriate context.
  - For example, while we typically avoid the use of the term “powwow”, in the following context, it’s appropriate: “Bear Witness is a co-founder of A Tribe Called Red, a Canadian DJ collective that blends hip-hop and EDM with traditional powwow drums and vocals” (from [Vanguard: How A Tribe Called Red Brought Activism to the Dance Floor](https://www.shopify.com/blog/vanguard-a-tribe-called-red)).

<br>

### Words and phrases to avoid

Avoid the following words and phrases.

<h4 id="exotic">Exotic</h4>

Consider why you need to frame someone or something this way. What is “foreign” or “exotic” to you is familiar for someone else.

<h4 id="grandfather">Grandfather in, grandfather clause</h4>

These phrases come from laws meant to circumvent or disenfranchise Black people’s rights. These laws, or “grandfather clauses” originated in the Reconstruction era in the American South.

<!-- usagelist -->

#### Do

- Legacy, legacied
- Exempt

#### Don’t

- Grandfather in, grandfathered in
- Grandfather clause

<!-- end -->

<h4 id="powwow">Powwow</h4>

A powwow is a celebration of heritage, art, and community held by Indigenous people, and should only be used to refer to actual powwows. Use other terms to refer to meetings and events that aren’t powwows.

<!-- usagelist -->

#### Do

- Meet, meeting
- Gather, get together
- Assemble, assembly
- Regroup

#### Don’t

- Powwow

<!-- end -->

<h4 id="spirit-animal">Spirit animal</h4>

Indigenous communities use spirit animals as totems and guides. A spirit animal has deep spiritual and cultural meaning, and should only be used in that context. Don’t say spirit animal to mean the animal a non-Indigenous person might identify with the most.

<h4 id="black-hat-white-hat">Black hat, white hat (hacking)</h4>

These terms imply that “white is good” and “black is bad”.

<!-- usagelist -->

#### Do

- Unethical hacking
- Ethical hacking

#### Don’t

- Black hat
- White hat

<!-- end -->

<h4 id="blacklist-whitelist">Blacklist, whitelist</h4>

These terms enforce the “white is good” and “black is bad” paradigm.

<!-- usagelist -->

#### Do

- Denylist, blocklist
- Allowlist
- Permit, permitted

#### Don’t

- Blacklist
- Whitelist
- Graylist

<!-- end -->

<!-- usageblock -->

#### Do

Learn how to secure a compromised account and reset blocked credentials.

#### Don’t

Learn how to secure a compromised account and reset blacklisted credentials.

<!-- end -->

<!-- usageblock -->

#### Do

Add no-reply[at]shopify.com to your email provider’s allowlist.

#### Don’t

Add no-reply[at]shopify.com to your email provider’s whitelist.

<!-- end -->

<h4 id="cakewalk">Cakewalk</h4>

This term originates from a dance contest where enslaved Black people competed for cake.

<!-- usagelist -->

#### Do

You can easily file your your taxes with our latest features.

#### Don’t

It’s a cakewalk to file your taxes with our latest features.

<!-- end -->

<h4 id="whitespace">Whitespace</h4>

This term refers to communities and places that are predominantly white and that might make non-white people feel restricted or isolated. Avoid using this term except when referring to the named property in CSS.

<!-- usagelist -->

#### Do

- New market opportunity/new market space
- Unmet need/unexplored opportunity
- Emptyspace

#### Don’t

- Whitespace

<!-- end -->

<h4 id="long-time-no-see">Long time no see</h4>

This phrase was used to stereotype Indigenous peoples as unintelligent, and shouldn’t be used due to its racist origins.

<!-- usagelist -->

#### Do

It’s been a while

#### Don’t

Long time no see

<!-- end -->

<h4 id="low-hanging-fruit">Low-hanging fruit</h4>

This metaphor refers to the lynching of Black people, and shouldn’t be used.

<!-- usagelist -->

#### Do

- Prepare to launch your store by adding a new product.

#### Don’t

- Take care of low-hanging fruit on your task list by adding a new product.

<!-- end -->

---

## Ungendered content

<!-- keywords: gender, gendered, ungendered, sex, gender identity, gender binary, they, gender-neutral, gender-inclusive, pronouns -->

Gendered language is language biased towards a particular sex or gender. Language that relies on stereotypes, or makes broad assumptions about its audiences’ sex or gender identities is likely gendered.

Ungendered content doesn’t mean avoiding gendered terms—it means being intentional about how you use gendered terms.

**Tips:**

- When a subject is unknown, use “they”, “you”, or “we”.
- Be conscious of perpetuating stereotypes, like assuming that a merchant might only have a “men’s collection” or a “women’s collection”.
- Avoid asking for pronouns or gender unless they’re required (or offered).
- Don’t associate specific qualities with a specific gender, like linking positions of power with men. For example, judge, doctor, lawyer.

At Shopify, we believe ungendered language expands and improves the ways we talk—it makes us more accurate, more precise, and more inclusive.

### Internationalization

Many languages lack gender-inclusive options, like the pronoun “they” in English. Try to avoid gendered language whenever possible by writing what you want to say in a different way, even if it’s longer. If gender-neutral language isn’t possible, then choose the expression that’s most understandable.

When possible, don’t use gendered pronouns. Use the “you” pronoun instead of the third person “she/he”. Find alternatives to gendered adjectives, like indefinite adjectives, substantives, or objects.

### Words and phrases to avoid

Avoid the following words and phrases.

<h4 id="female-adaptor">Female or male adapter or female or male connector</h4>

These terms reinforce the idea that gender is binary.

<!-- usagelist -->

#### Do

- Socket
- Input

#### Don’t

- Female adaptor
- Female connector

<!-- end -->

<h4 id="businessman">Businessman</h4>

This term can exclude people who aren’t men and reinforce the idea that positions of power are only for men. Use a word that’s gender-neutral and inclusive of all people.

<!-- usagelist -->

#### Do

- Businessperson

#### Don’t

- Businessman

<!-- end -->

<h4 id="manned">Manned</h4>

This term excludes people who aren’t men. Use a word that’s gender-neutral and inclusive of all people.

<!-- usagelist -->

#### Do

- Staffed
- Managed

#### Don’t

- Manned

<!-- end -->

<h4 id="man-made">Man-made</h4>

This word can exclude people who aren’t men. Use a word that’s gender-neutral and inclusive of all people.

<!-- usagelist -->

#### Do

- Artificial
- Synthetic
- Manufactured
- Fabricated

#### Don’t

- Man-made

<!-- end -->

<h4 id="manpower">Manpower</h4>

This word can also exclude people who aren’t men.

<!-- usagelist -->

#### Do

- Workforce
- Labor force

#### Don’t

- Manpower

<!-- end -->

<h4 id="man-woman">Man, woman</h4>

These terms assume a binary gender which might not be the case. Consider how you use these terms and if they’re necessary in that particular context. If you’re listing genders, make sure to include all genders.

<!-- usagelist -->

#### Do

- Person
- Individual

#### Don’t

- Man
- Woman

<!-- end -->

<h4 id="pronouns">He/him/his, she/her/hers</h4>

These terms assume a binary gender which might not be the case. Consider how you use these terms and if they’re necessary in that particular context.

<!-- usagelist -->

#### Do

- They/them/theirs

#### Don’t

- He/him/his
- She/her/hers

<!-- end -->
