---
name: Content/Vocabulary
slug: vocabulary
icon: IconVocabulary
keywords:
  - spelling
  - vocabulary list
  - dictionary
  - shopify dictionary
  - shopify vocabulary
  - shopify terms
  - caps
  - capitalizations
  - definitions
  - define
  - spelling
  - terms
---

# Vocabulary

It’s important to use the same words, spelling, and capitalization consistently,
otherwise things start looking messy and confusing for merchants.

In general, if a feature or product isn’t unique to Shopify, such as a blog, then don’t capitalize it. If it’s unique to Shopify and marketable as
its own product, such as Shopify Shipping, then capitalize it. Edge cases are
assessed individually and documented here.

Use American English spelling for all merchant-facing content. When in doubt,
check the [Merriam-Webster dictionary](https://www.merriam-webster.com/) for the
preferred spelling of specific terms not found in this list.

---

## A: account, admin…

#### <a name="definition-a-account"></a>account

The relationship between a user and Shopify.
A user has one account, which allows them to access their stores,
the Shopify Partner Program, Shopify Academy, and Shopify Community.

Tip: “store” and “account” are not interchangeable.

<!-- usagelist -->

#### Do

- Your account has access to 5 stores.
- Log in to your account.

#### Don’t

- You have 5 accounts.
- Log in to your store.
- Your profile has access to 5 stores.

<!-- end -->

#### <a name="definition-a-admin"></a>admin, Shopify admin

This is the Shopify product merchants use to manage their store.

Example: Log in to your Shopify admin.

#### <a name="definition-a-app"></a>app

An abbreviation for application. A software program designed to perform a
specific function directly for the user or another app.

Apps can be integrated with Shopify to enhance functions and features. The
Shopify App Store has both paid and free apps built by Shopify and partners.

Example: List your app in the Shopify App Store.

---

## B: Black Friday Cyber Monday…

#### <a name="definition-b-bfcm"></a>Black Friday Cyber Monday

A major shopping weekend in North America that marks the start of the holiday
shopping season. Since customers are already hunting for deals, Black Friday
Cyber Monday is a good opportunity for merchants to boost their sales.

Example: Create a Black Friday Cyber Monday discount to boost sales

Tip: In the admin, we should always default to using Black Friday Cyber Monday.
You can use the acronym BFCM only if you’ve introduced the full name first.

<!-- usagelist -->

#### Do

- Black Friday Cyber Monday
- BFCM

#### Don’t

- Black Friday and Cyber Monday
- Black Friday, Cyber Monday
- Black Friday & Cyber Monday
- Black Friday/Cyber Monday
- bfcm

<!-- end -->

#### <a name="definition-b-blog"></a>blog

A regularly updated website or web page written in an informal or conversational
style, run by companies, individuals, or groups.

Shopify has several blogs including an Ecommerce blog, Web Design and
Development blog, and Shopify UX blog.

Merchants can add a blog to their online store to boost search engine
optimization (SEO), promote their products, and build a community around their
brand.

Example: A blog can help you build a community around your products and your
brand.

#### <a name="definition-b-blog-page"></a>blog page

A web page that displays blog posts.

Merchants can add multiple blog pages to their online store.

Example: You can add a blog page to your online store for content that you’ll be
updating regularly, or if you want to encourage feedback.

#### <a name="definition-b-blog-posts"></a>blog posts

A piece of writing or other type of content published to a blog. Often written
in an informal or conversational style.

Merchants can write, add, publish, and unpublish blog posts to blog pages on
their online store.

Example: After you’ve created a blog, you can get started on your first blog
post.

#### <a name="definition-b-buy-button"></a>Buy Button, Shopify Buy Button

Shopify’s sales channel that lets merchants add ecommerce functionality to their
website, blog, or email campaign. Shopify Buy Buttons connect customers to the
Shopify checkout.

Example: Match any web page’s theme by customizing the style and format of your
Buy Buttons and embedded cart.

---

## C: cart page, check out…

#### <a name="definition-c-cart-page"></a>cart page, shopping cart, shopping cart page

The page a customer sees before they proceed to checkout with a summary of their
order.

Example: A shipping rates calculator on your cart page helps customers estimate
their shipping costs before completing checkout.

<!-- usagelist -->

#### Do

- cart page
- shopping cart
- shopping cart page

#### Don’t

- checkout page
- basket page
- bag

<!-- end -->

#### <a name="definition-c-check-out-verb"></a>check out (verb)

1.  To pay for items and complete an order.
2.  Look at, read, or review something to determine its value or usefulness.

Examples:

1.  Customers want to see a summary of the items in their cart before they check
    out.
2.  Check out these tips to improve your email marketing strategy.

<!-- usagelist -->

#### Do

- check out

#### Don’t

- checkout
- check-out

<!-- end -->

#### <a name="definition-c-checkout-noun"></a>checkout (noun)

The place where customers pay for their items.

The part of a store that accepts orders and takes payments. Wherever merchants
sell online, they use Shopify’s secure checkout to accept orders and take
payments.

Example: Use your secure Shopify checkout to accept orders and take payments.

<!-- usagelist -->

#### Do

- checkout

#### Don’t

- check out
- check-out

<!-- end -->

#### <a name="definition-c-collections"></a>collections

Products grouped together into categories. Used to make products easier to
manage or easier for customers to discover.

Example: Add a title and description to see how this collection might appear in
a search engine listing.

#### <a name="definition-c-country/region"></a>country/region

An attribute of a domain, product, or any physical address. A country/region can take different forms, which is why this term includes country and region:

- Country: Italy
- Country made up of other countries: United Kingdom
- Autonomous region: Taiwan

Example: Manage country/region pricing

<!-- usagelist -->

#### Do

- country/region
- countries/regions

#### Don’t

- country

<!-- end -->

#### <a name="definition-c-customers"></a>customers

A person or organization who interacts with a Shopify merchant or their sales channel.

For example: Customers will get a discount if they enter a code at checkout.

In the Shopify admin and POS, a customer appears on the Customers page when they engage with a merchant in an identifiable way. This could be because they:

- were added or imported by the merchant
- started a purchase but abandoned it at checkout
- made a purchase
- create a customer account
- subscribed to the merchant's mailing list

Tip: Avoid using “returning customer” (or other adjectives that imply a customer made a purchase) in contexts where merchants need a precise understanding of how their business is operating, such as analytics.

<!-- usagelist -->

#### Do

- customer
- customers

#### Don’t

- returning customers

<!-- end -->

---

## D: dev store, digital…

#### <a name="definition-d-development-store"></a>development store, dev store

A store where Partners can build and test freely.

Shopify Partners have the ability to create an unlimited number of development
stores to use for demo or portfolio purposes, or as the first step in signing up
clients for Shopify. When dev stores are handed off to the merchant/client, they
become managed stores.

Example: Dev stores have the full range of features included with the Advanced
Shopify plan.

#### <a name="definition-d-digital-wallet"></a>digital wallet

A service that allows a customer to pay through a payment provider without
entering their credit card information.

Apple Pay is an example of a digital wallet that works with many different
payment providers. Some digital wallet services, like Amazon Pay, come with
their own payment provider.

Example: Understand the digital wallet your customer used during a transaction.

#### <a name="definition-d-dropshipping"></a>dropshipping

A third-party fulfillment service or warehouse that prepares and ships
merchants’ orders for them.

Example: Choose from available fulfillment and dropshipping services that will
ship your orders for you.

---

## E: ecommerce, email…

#### <a name="definition-e-ecommerce"></a>ecommerce

Buying or selling online.

Example: Shopify’s ecommerce university guides are a rich resource for budding
entrepreneurs.

#### <a name="definition-e-email-template"></a>email template

The place where merchants customize the emails that get sent to them, their
staff, or their customers. They can adjust preformatted and prewritten emails
templates with their own content and formatting.

Example: These emails are automatically sent out to either you or the customer.
Click on the email templates below to edit.

---

## F: fulfill, fulfillment…

#### <a name="definition-f-fulfill-verb"></a>fulfill (verb)

Bring an order or package to completion. When we say that an order has been
completely fulfilled, we mean all the items in that order have been sent to the
customer.

Example: Fulfill all items for an order and send the shipping confirmation
email.

#### <a name="definition-f-fulfillment"></a>fulfillment

The steps involved in receiving, processing, and delivering orders to customers.

Example: Save time and money on order fulfillment by using Shopify Shipping to
buy and print USPS or Canada Post shipping labels.

---

## H: home card…

#### <a name="definition-h-home-card"></a>home card

A special component of Shopify Home. Home cards give merchants insights about
their business, suggestions on how to improve, and important communications from
Shopify. Unlike referring to Shopify Home, the term home card should only be
capitalized when it comes at the beginning of a sentence.

Example: Shopify Home contains timely alerts, news, and guidance in one
actionable feed. The content is presented through home cards.

<!-- usagelist -->

#### Do

- home card

#### Don’t

- card
- in-app advertisements
- notifications

<!-- end -->

---

## I: inventory, item…

#### <a name="definition-i-inventory"></a>inventory

A store’s complete list of variants. Includes SKU, barcode, tracking information, quantity, and locations each variant is stocked.

Example: Manage inventory and orders across all your locations.

#### <a name="definition-i-item"></a>item

One unit of a product. If a product has variants, an item is one unit of a
variant.

Examples:

1.  The customer has 5 items in their cart.
2.  Automatically fulfill items in an order.

<!-- usagelist -->

#### Do

- item

#### Don’t

- line item

<!-- end -->

---

## L: log in, login…

#### <a name="definition-l-log-in-verb"></a>log in (verb)

The act of entering a username and password to securely use Shopify and
authenticate yourself.

Example: Install and log in to the Shopify app.

#### <a name="definition-l-login-noun"></a>login (noun)

User credentials, such as a username, Shopify store name, and password.

Example: As the account owner or a user with full access, you can see the login
history of any staff member.

---

## M: merchant…

#### <a name="definition-m-merchant"></a>merchant

Someone who sells items or services.

Merchants use Shopify or have a Shopify account to run their business. There are
many different types of Shopify merchants.

Example: Merchants often operate a retail business and some offer services.

---

## O: online store…

#### <a name="definition-o-online-store"></a>online store

A merchant’s ecommerce website. It’s one of many sales channels that a merchant
can use to sell products and services through the Shopify platform. Other sales
channels include Facebook, Pinterest, Shopify POS, and Buy Button.

Example: Add products to your online store.

---

## P: password page, payment…

#### <a name="definition-p-password-page"></a>password page

The landing page for an online store that’s been hidden from the public and
accessible only by a password that’s set by the merchant.

Example: You can add a password page to your theme.

<!-- usagelist -->

#### Do

- password page

#### Don’t

- storefront password

<!-- end -->

#### <a name="definition-p-payment-method"></a>payment method

Used to describe a specific way a customer can pay such as Visa, MasterCard, or
Apple Pay.

Example: Select alternative payment method.

Tip: It’s fine to use this term informally.

Example: You’re paying with MasterCard vs. Your payment method is MasterCard.

#### <a name="definition-p-payment-provider"></a>payment provider

The gateway a merchant chooses to accept payments for their store.

Example: Your current payment providers are Shopify Payments and Paypal.

<!-- usagelist -->

#### Do

- payment provider

#### Don’t

- gateway
- payment gateway

<!-- end -->

#### <a name="definition-p-pick-up-verb"></a>pick up (verb)

To collect something that has been left elsewhere.

Shopify merchants may have customers who pick up their orders directly from
them.

Example: Waiting for the customer to pick up their order.

<!-- usagelist -->

#### Do

- pick up

#### Don’t

- pickup
- pick-up
- Pick Up

<!-- end -->

#### <a name="definition-p-pickup-noun"></a>pickup (noun)

The act of collecting something.

Merchants may make products available for pickup to their customers.

Example: In-store pickup.

<!-- usagelist -->

#### Do

- pickup

#### Don’t

- pick up
- pick-up
- Pickup

<!-- end -->

#### <a name="definition-p-pop-up-shop"></a>pop-up shop

A short-term, temporary retail event hosted at a physical location.

Example: Pop-up shops can create lasting impressions with potential customers
because of their unique, time-limited, and engaging retail environment.

<!-- usagelist -->

#### Do

- pop-up shop

#### Don’t

- pop up shop
- popup shop

<!-- end -->

#### <a name="definition-p-product"></a>product

Physical goods, digital downloads, services, and gift cards that merchants sell
on their Shopify store. If products come in more than one option, like size or
color, merchants can add variants for each combination of options.

Example: You can duplicate products you’ve created on the product page.

---

## S: sales channel, Shopify…

#### <a name="definition-s-sales-channel"></a>sales channel

Places where merchants sell items, such as an online store, Pinterest, or
Facebook. Merchants connect sales channels to their Shopify store where they can
keep track of their orders, products, and customers in one place, no matter what
they’re selling.

Example: Merchants are always interested in adding sales channels that will put
their products in front of a new group of customers.

#### <a name="definition-s-shopify-payments"></a>Shopify Payments

Shopify’s payment processing service. Shopify Payments lets merchants accept
credit cards and Apple Pay through their checkout, Shopify POS, and other sales
channels.

Example: Add Shopify Payments to accept credit cards and Apple Pay through your
online store and other sales channels.

#### <a name="definition-s-shopify-point-of-sale"></a>Shopify POS, Shopify Point of Sale

Shopify’s Point of Sale app that’s used on tablets and smartphones to sell
in person and accept payments.

Example: With Shopify POS you can sell your products and accept payment on any
device.

#### <a name="definition-s-shopify-support"></a>Shopify Support

The Shopify team that merchants can contact by phone, email, or chat for support with using Shopify products.

Example: Contact Shopify Support for help with setting up your custom domain.

#### <a name="definition-s-store"></a>store

A retail establishment for selling items to customers.

Example: Turn any website into an online store. Embed your product in WordPress,
Squarespace, Tumblr, and others using Shopify’s Buy Button.

Tip: Use “store” instead of “shop” to prevent sentences like, “your Shopify
shop.”

Tip: “Store” and “account” are not interchangeable. A user has one account, which allows them to access all of their stores and services on Shopify.

<!-- usagelist -->

#### Do

- store
- Add products to your store

#### Don’t

- shop
- Add products to your account

<!-- end -->

---

## T: template, theme…

#### <a name="definition-t-template"></a>template

A preformatted and/or prewritten document or file users can customize with their
own content.

Shopify stores have email notification and website templates (see “themes”),
among others.

Example: The software includes templates for common marketing documents like
emails.

#### <a name="definition-t-theme"></a>theme

A website template.

Merchants can upload and customize their theme to change the look and feel of
their online store.

Example: Use a theme to create a beautiful online store customized to your
brand.

Tip: Use “Theme” as the primary term, but use “website template” in descriptions
to add context for merchants who don’t know what a theme is yet.

#### <a name="definition-t-third-party-noun"></a>third party (noun)

A person or group who is indirectly involved but is not a principal party to an
arrangement, contract, deal, lawsuit, or transaction.

Example: The transaction involved a third party.

#### <a name="definition-t-third-party-adjective"></a>third-party (adjective)

Merchants can use a third-party credit card provider. Dropshippers are a
third-party order fulfillment service. Shopify Partners are third-party
designers, developers, and creatives.

Example: Complete the verification steps on the third-party site.

#### <a name="definition-t-timeline"></a>Timeline

A detailed chronological history for orders, draft orders, customers, and
transfers. Merchants can write internal notes or comments and mention other
staff accounts on Timeline.

Example: If you use the Shopify app, you can receive notifications whenever
you’re mentioned in a Timeline comment.

<!-- usagelist -->

#### Do

- Timeline

#### Don’t

- timeline
- feed

<!-- end -->

---

## V: variant...

#### <a name="definition-v-variant"></a>variant

Merchants can add variants to a product that comes in more than one option, like
size or color. Each combination of options is a variant.

Example: You can show different product images for each variant.
